==> haskell-glib-0.13.4.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-glib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: glib
version: 0.13.4.1
id: glib-0.13.4.1-6JZW7jufw4hIaaKiUUOHkH
key: glib-0.13.4.1-6JZW7jufw4hIaaKiUUOHkH
license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the GLIB library for Gtk2Hs.
description:
    GLib is a collection of C data structures and utility functions
    for the GObject system, main loop implementation, for strings and
    common data structures dealing with Unicode. This package only binds
    as much functionality as required to support the packages that
    wrap libraries that are themselves based on GLib.
category: System
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules:
    System.Glib System.Glib.GError System.Glib.Properties
    System.Glib.Attributes System.Glib.Signals System.Glib.MainLoop
    System.Glib.GDateTime System.Glib.GObject System.Glib.Utils
    System.Glib.StoreValue System.Glib.FFI System.Glib.Flags
    System.Glib.UTFString System.Glib.Types System.Glib.GList
    System.Glib.GString System.Glib.GType System.Glib.GTypeConstants
    System.Glib.GValue System.Glib.GValueTypes System.Glib.GParameter
abi: 2e3a960ee8c777c481874cf998563fc7
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/glib-0.13.4.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/glib-0.13.4.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/glib-0.13.4.1
hs-libraries: HSglib-0.13.4.1-6JZW7jufw4hIaaKiUUOHkH
extra-libraries:
    gobject-2.0 glib-2.0
include-dirs: /usr/include/glib-2.0 /usr/lib/glib-2.0/include
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
haddock-interfaces: /usr/share/doc/haskell-glib/html/glib.haddock
haddock-html: /usr/share/doc/haskell-glib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-glib-0.13.4.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-glib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: glib
version: 0.13.4.1
id: glib-0.13.4.1-EEQaey3pIjy8n9nCCarNfz
key: glib-0.13.4.1-EEQaey3pIjy8n9nCCarNfz
license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the GLIB library for Gtk2Hs.
description:
    GLib is a collection of C data structures and utility functions
    for the GObject system, main loop implementation, for strings and
    common data structures dealing with Unicode. This package only binds
    as much functionality as required to support the packages that
    wrap libraries that are themselves based on GLib.
category: System
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules:
    System.Glib System.Glib.GError System.Glib.Properties
    System.Glib.Attributes System.Glib.Signals System.Glib.MainLoop
    System.Glib.GDateTime System.Glib.GObject System.Glib.Utils
    System.Glib.StoreValue System.Glib.FFI System.Glib.Flags
    System.Glib.UTFString System.Glib.Types System.Glib.GList
    System.Glib.GString System.Glib.GType System.Glib.GTypeConstants
    System.Glib.GValue System.Glib.GValueTypes System.Glib.GParameter
abi: c3758c928cc85fb883427bb4cffe9029
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/glib-0.13.4.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/glib-0.13.4.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/glib-0.13.4.1
hs-libraries: HSglib-0.13.4.1-EEQaey3pIjy8n9nCCarNfz
extra-libraries:
    gobject-2.0 glib-2.0
include-dirs: /usr/include/glib-2.0 /usr/lib/glib-2.0/include
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
haddock-interfaces: /usr/share/doc/haskell-glib/html/glib.haddock
haddock-html: /usr/share/doc/haskell-glib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
